<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="choqok" version="14">
<MenuBar>
  <Menu name="file"><text>File</text>
    <Action name="choqok_new_post" />
    <Action name="update_timeline" />
    <Action name="choqok_mark_as_read" />
    <Separator/>
    <Action name="toggle_mainwin"/>
  </Menu>
  <Menu name="tools"><text>Tools</text>
    <Action name="choqok_clear_avatar_cache"/>
    <Action name="choqok_upload_medium"/>
  </Menu>
  <Menu name="settings"><text>Settings</text>
    <Action name="choqok_enable_updates"/>
    <Action name="choqok_hide_menubar"/>
    <Action name="settings_notifications" append="configure_merge"/>
  </Menu>
  <Menu name="help"><text>Help</text>
    <Action name="choqok_donate" append="about_merge"/>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar" position="top">
  <Action name="choqok_new_post"/>
  <Action name="update_timeline"/>
  <Action name="choqok_upload_medium"/>
</ToolBar>
</gui>
