<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="choqok" version="4">
    <MenuBar>
        <Menu name="tools"><text>Tools</text>
            <Action name="search" />
        </Menu>
    </MenuBar>
</gui>
